OC.L10N.register(
    "files_reminders",
    {
    "Set file reminders" : "Cunfigura apuntos de archìviu",
    "Set reminder for \"{fileName}\"" : "Cunfigura un'apuntu pro \"{fileName}\"",
    "Set reminder at custom date & time" : "Cunfigura un'apuntu pro una data e ora ispetzìfica",
    "Reminder set for \"{fileName}\"" : "Apuntu cunfiguradu pro \"{fileName}\"",
    "Failed to set reminder" : "Errore in sa cunfiguratzione de s'apuntu",
    "Cancel" : "Annulla",
    "Set reminder" : "Cunfigura un'apuntu",
    "Set custom reminder" : "Cunfigura un'apuntu personalizadu",
    "Set reminder for later today" : "Cunfigura un'apuntu pro luego",
    "Tomorrow" : "Cras",
    "Set reminder for tomorrow" : "Cunfigura un'apuntu pro cras",
    "Set reminder for this weekend" : "Cunfigura un'apuntu pro custu fine de chida",
    "Next week" : "Sa chida chi benit",
    "Set reminder for next week" : "Cunfigura un'apuntu pro chida chi benit"
},
"nplurals=2; plural=(n != 1);");
